import os

from gi.repository import Gtk
from gi.repository import WebKit
from gi.repository import GConf

from jarabe import config


def setup_theme():
    settings = Gtk.Settings.get_default()
    sugar_theme = 'sugar-72'
    if 'SUGAR_SCALING' in os.environ:
        if os.environ['SUGAR_SCALING'] == '100':
            sugar_theme = 'sugar-100'
    settings.set_property('gtk-theme-name', sugar_theme)
    settings.set_property('gtk-icon-theme-name', 'sugar')

    icons_path = os.path.join(config.data_path, 'icons')
    Gtk.IconTheme.get_default().append_search_path(icons_path)

def setup_fonts():
    client = GConf.Client.get_default()
    face = client.get_string('/desktop/sugar/font/default_face')
    size = client.get_float('/desktop/sugar/font/default_size')
    settings = Gtk.Settings.get_default()
    settings.set_property("gtk-font-name", "%s %f" % (face, size))

setup_fonts()
setup_theme()

CSS_STYLE = """
body {
  background-color: #ffffff;
}
audio, video {
  width: 500px;
  height: 55px;
  color: #ffffff;
}
audio::-webkit-media-controls-enclosure, video::-webkit-media-controls-enclosure {
  height: 55px;
}
audio::-webkit-media-controls-panel, video::-webkit-media-controls-panel {
  height: 55px;
  background-color: #282828;
  border-radius: 25px;
}
audio::-webkit-media-controls-mute-button, video::-webkit-media-controls-mute-button,
audio::-webkit-media-controls-play-button, video::-webkit-media-controls-play-button,
audio::-webkit-media-controls-toggle-closed-captions-button, video::-webkit-media-controls-toggle-closed-captions-button,
audio::-webkit-media-controls-fullscreen-button, video::-webkit-media-controls-fullscreen-button,
audio::-webkit-media-controls-seek-back-button, video::-webkit-media-controls-seek-back-button,
audio::-webkit-media-controls-seek-forward-button, video::-webkit-media-controls-seek-forward-button {
  width: 55px;
  height: 55px;
}
audio::-webkit-media-controls-current-time-display, video::-webkit-media-controls-current-time-display,
audio::-webkit-media-controls-time-remaining-display, video::-webkit-media-controls-time-remaining-display {
  height: 55px;
  line-height: 0px;
  font-size: 23px;
  text-align: center;
}
""".replace('\n', '')

INJECT_STYLE_SCRIPT = """
var style = document.createElement('style');
style.innerHTML = '%s';
document.body.appendChild(style);
""" % CSS_STYLE


class MyWindow(Gtk.Window):
    def __init__(self):
        Gtk.Window.__init__(self)
        self.resize(800, 600)
        self.connect('destroy', lambda w: Gtk.main_quit())

        scrolled = Gtk.ScrolledWindow()
        self.add(scrolled)
        scrolled.show()

        self.inject_style = False

        view = WebKit.WebView()
        view_settings = view.get_settings()
        view_settings.props.enable_file_access_from_file_uris = True
        view.set_settings(view_settings)

        view.connect('notify::load-status', self.on_load_status)
        view.connect('load-error', self.load_error_cb)
        view.connect('mime-type-policy-decision-requested',
                     self.mime_type_policy_cb)

        view.load_uri("file:///home/olpc/Library/JamendoMusic/2970.ogg")
        scrolled.add(view)
        view.show()

    def on_load_status(self, widget, param):
        status = widget.get_load_status()

    def mime_type_policy_cb(self, web_view, web_frame, request, mimetype,
                            policy_decision):
        if mimetype == 'audio/x-vorbis+ogg':
            self.inject_style = True

    def load_error_cb(self, web_view, web_frame, uri, web_error):
        if web_error.code in (WebKit.PolicyError.\
                FRAME_LOAD_INTERRUPTED_BY_POLICY_CHANGE,
                WebKit.PluginError.WILL_HANDLE_LOAD):
            if self.inject_style:
                web_view.execute_script(INJECT_STYLE_SCRIPT)


window = MyWindow()
window.show()

Gtk.main()
